diff --git a/App/Containers/HomeScreen.js b/App/Containers/HomeScreen.js
index 737d6b7f3..d3c26b526 100644
--- a/App/Containers/HomeScreen.js
+++ b/App/Containers/HomeScreen.js
@@ -25,7 +25,7 @@ class HomeScreen extends React.Component {
The weather temperature is: {this.props.temperature}
{this.props.isHot ? "It's pretty hot!" : ''}
- {this.props.errorMessage}
+ {this.props.temperatureErrorMessage}
)
@@ -51,12 +51,12 @@ const styles = StyleSheet.create({
HomeScreen.propsTypes = {
temperature: PropTypes.number,
- errorMessage: PropTypes.string,
+ temperatureErrorMessage: PropTypes.string,
}
const mapStateToProps = (state) => ({
temperature: state.example.get('temperature'),
- errorMessage: state.example.get('errorMessage'),
+ temperatureErrorMessage: state.example.get('temperatureErrorMessage'),
isHot: isHot(state),
})
diff --git a/App/Stores/Example/InitialState.js b/App/Stores/Example/InitialState.js
index e3abd1770..8f8a2b1b5 100644
--- a/App/Stores/Example/InitialState.js
+++ b/App/Stores/Example/InitialState.js
@@ -5,5 +5,5 @@ import { Map } from 'immutable'
*/
export const INITIAL_STATE = Map({
temperature: null,
- errorMessage: null,
+ temperatureErrorMessage: null,
})
diff --git a/App/Stores/Example/Reducers.js b/App/Stores/Example/Reducers.js
index f8abd21c8..1a8af52db 100644
--- a/App/Stores/Example/Reducers.js
+++ b/App/Stores/Example/Reducers.js
@@ -8,16 +8,16 @@ import { ExampleTypes } from './Actions'
export const updateTemperature = (state, { temperature }) =>
state.merge({
temperature: temperature,
- errorMessage: null,
+ temperatureErrorMessage: null,
})
/**
* Example of a reducer that updates the `errorMessage` property.
*/
export const showErrorMessage = (state, { errorMessage }) =>
state.merge({
temperature: '??',
- errorMessage: errorMessage,
+ temperatureErrorMessage: errorMessage,
})
/**
@@ -8,16 +8,16 @@ import { ExampleTypes } from './Actions'
})
/**
- * Example of a reducer that updates the `errorMessage` property.
+ * Example of a reducer that updates the `temperatureErrorMessage` property.
*/
export const showErrorMessage = (state, { errorMessage }) =>